@@ -46,18 +46,31 @@ import aws_cdk.custom_resources
 import constructs
 
 
+@jsii.enum(jsii_type="@renovosolutions/cdk-library-aws-organization.OrgObjectTypes")
+class OrgObjectTypes(enum.Enum):
+    '''The supported OrgObject types.'''
+
+    OU = "OU"
+    ACCOUNT = "ACCOUNT"
+
+
 class OrganizationOU(
     constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@renovosolutions/cdk-library-aws-organization.OrganizationOU",
 ):
+    '''The construct to create or update an Organization OU.
+
+    This relies on the custom resource provider OrganizationOUProvider.
+    '''
+
     def __init__(
         self,
         scope: constructs.Construct,
         id: builtins.str,
         *,
         name: builtins.str,
-        parent_id: builtins.str,
+        parent: typing.Union[builtins.str, "OrganizationOU"],
         provider: aws_cdk.custom_resources.Provider,
         allow_merge_on_move: typing.Optional[builtins.bool] = None,
         allow_recreate_on_update: typing.Optional[builtins.bool] = None,
@@ -67,7 +80,7 @@ class OrganizationOU(
         :param scope: -
         :param id: -
         :param name: The name of the OU.
-        :param parent_id: The parent OU id.
+        :param parent: The parent OU id.
         :param provider: The provider to use for the custom resource that will create the OU. You can create a provider with the OrganizationOuProvider class
         :param allow_merge_on_move: Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs. If this is false and the OU already exists an error will be thrown. If this is true and the OU already exists the accounts in the OU will be moved to the existing OU and the duplicate, now empty, OU will be deleted. Default: false
         :param allow_recreate_on_update: Whether or not a missing OU should be recreated during an update. If this is false and the OU does not exist an error will be thrown when you try to update it.
@@ -75,7 +88,7 @@ class OrganizationOU(
         '''
         props = OrganizationOUProps(
             name=name,
-            parent_id=parent_id,
+            parent=parent,
             provider=provider,
             allow_merge_on_move=allow_merge_on_move,
             allow_recreate_on_update=allow_recreate_on_update,
@@ -95,7 +108,7 @@ class OrganizationOU(
     jsii_struct_bases=[],
     name_mapping={
         "name": "name",
-        "parent_id": "parentId",
+        "parent": "parent",
         "provider": "provider",
         "allow_merge_on_move": "allowMergeOnMove",
         "allow_recreate_on_update": "allowRecreateOnUpdate",
@@ -107,15 +120,16 @@ class OrganizationOUProps:
         self,
         *,
         name: builtins.str,
-        parent_id: builtins.str,
+        parent: typing.Union[builtins.str, OrganizationOU],
         provider: aws_cdk.custom_resources.Provider,
         allow_merge_on_move: typing.Optional[builtins.bool] = None,
         allow_recreate_on_update: typing.Optional[builtins.bool] = None,
         import_on_duplicate: typing.Optional[builtins.bool] = None,
     ) -> None:
-        '''
+        '''The properties of an OrganizationOU custom resource.
+
         :param name: The name of the OU.
-        :param parent_id: The parent OU id.
+        :param parent: The parent OU id.
         :param provider: The provider to use for the custom resource that will create the OU. You can create a provider with the OrganizationOuProvider class
         :param allow_merge_on_move: Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs. If this is false and the OU already exists an error will be thrown. If this is true and the OU already exists the accounts in the OU will be moved to the existing OU and the duplicate, now empty, OU will be deleted. Default: false
         :param allow_recreate_on_update: Whether or not a missing OU should be recreated during an update. If this is false and the OU does not exist an error will be thrown when you try to update it.
@@ -123,7 +137,7 @@ class OrganizationOUProps:
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
-            "parent_id": parent_id,
+            "parent": parent,
             "provider": provider,
         }
         if allow_merge_on_move is not None:
@@ -141,11 +155,11 @@ class OrganizationOUProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def parent_id(self) -> builtins.str:
+    def parent(self) -> typing.Union[builtins.str, OrganizationOU]:
         '''The parent OU id.'''
-        result = self._values.get("parent_id")
-        assert result is not None, "Required property 'parent_id' is missing"
-        return typing.cast(builtins.str, result)
+        result = self._values.get("parent")
+        assert result is not None, "Required property 'parent' is missing"
+        return typing.cast(typing.Union[builtins.str, OrganizationOU], result)
 
     @builtins.property
     def provider(self) -> aws_cdk.custom_resources.Provider:
@@ -207,6 +221,11 @@ class OrganizationOUProvider(
     metaclass=jsii.JSIIMeta,
     jsii_type="@renovosolutions/cdk-library-aws-organization.OrganizationOUProvider",
 ):
+    '''The provider for OU custom resources.
+
+    This creates a lambda function that handles custom resource requests for creating/updating/deleting OUs.
+    '''
+
     def __init__(
         self,
         scope: constructs.Construct,
@@ -236,7 +255,8 @@ class OrganizationOUProvider(
 )
 class OrganizationOUProviderProps:
     def __init__(self, *, role: typing.Optional[aws_cdk.aws_iam.IRole] = None) -> None:
-        '''
+        '''The properties for the OU custom resource provider.
+
         :param role: The role the custom resource should use for taking actions on OUs if one is not provided one will be created automatically.
         '''
         self._values: typing.Dict[str, typing.Any] = {}
@@ -262,6 +282,7 @@ class OrganizationOUProviderProps:
 
 
 __all__ = [
+    "OrgObjectTypes",
     "OrganizationOU",
     "OrganizationOUProps",
     "OrganizationOUProvider",
